@@ -9,7 +9,7 @@
 #
 package Config::Model;
 {
-  $Config::Model::VERSION = '2.010';
+  $Config::Model::VERSION = '2.011';
 }
 use Any::Moose ;
 use namespace::autoclean;
@@ -96,7 +96,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.010
+version 2.011
 
 =head1 SYNOPSIS
 
@@ -2377,7 +2377,9 @@ Dominique Dumont, (ddumont at cpan dot org)
 
 L<Config::Model::Instance>,
 
-L<http://sourceforge.net/apps/mediawiki/config-model/index.php?title=Creating_a_model>
+L<https://github.com/dod38fr/config-model/wiki>
+
+L<https://github.com/dod38fr/config-model/wiki/Creating-models>
 
 =head2 Model elements
 
