@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 
 package Config::Model::Backend::Debian::Dpkg::Copyright ;
 {
-  $Config::Model::Backend::Debian::Dpkg::Copyright::VERSION = '1.260';
+  $Config::Model::Backend::Debian::Dpkg::Copyright::VERSION = '2.011';
 }
 
 use Any::Moose ;
@@ -53,9 +53,11 @@ sub read {
 
     my $check = $args{check} || 'yes';
 
-    $logger->info("Parsing $args{file} control file");
+    $logger->info("Parsing $args{file}");
+
     # load dpkgctrl file
     my $c = $self -> parse_dpkg_file ($args{io_handle}, $check) ;
+    return 0 unless @$c ; # no sections in file
     
     my $root = $args{object} ;
     my $file;
@@ -86,6 +88,8 @@ sub read {
                 if $check eq 'yes' ;
             warn("$str Adding 'Files: *' spec\n") ;
             $section{files} = '*' ;
+            # tell root node that read data was altered and needs to be written back
+            $root->needs_save(1) ;
         }
 
         if (defined $section{licence}) {
@@ -109,7 +113,7 @@ sub read {
             push @license_names, $lic_name ;
         }
         else {
-            my $str = "Unknow paragraph in section $section_nb. Is is a Files or a License section ?";
+            my $str = "Unknow paragraph in section $section_nb. Is it a Files or a License section ?";
             Config::Model::Exception::Syntax -> throw ( object => $self, error => $str ) 
                 if $check eq 'yes' ;
             $logger->warn("Dropping unknown paragraph from section $section_nb");
@@ -401,7 +405,7 @@ Config::Model::Backend::Debian::Dpkg::Copyright - Read and write Debian Dpkg Lic
 
 =head1 VERSION
 
-version 1.260
+version 2.011
 
 =head1 SYNOPSIS
 
