@@ -9,7 +9,7 @@
 #
 package Config::Model::Backend::Debian::DpkgSyntax ;
 {
-  $Config::Model::Backend::Debian::DpkgSyntax::VERSION = '2.008';
+  $Config::Model::Backend::Debian::DpkgSyntax::VERSION = '2.011';
 }
 
 use Any::Moose '::Role' ;
@@ -54,7 +54,7 @@ sub parse_dpkg_lines {
         if (/^#/) { # comment are always located before the keyword (hopefully)
             Config::Model::Exception::Syntax->throw (
                 object => $self,
-                line => $line,
+                parsed_line => $line,
                 message => "Comments are not allowed",
             ) unless $comment_allowed;
             my $c = $_ ;
@@ -98,7 +98,8 @@ sub parse_dpkg_lines {
         }
         else {
             my $msg = "DpkgSyntax error: Invalid line (missing ':' ?) : $_" ;
-            Config::Model::Exception::Syntax -> throw ( message => $msg, line => $line ) if $check eq 'yes' ; 
+            Config::Model::Exception::Syntax -> throw ( message => $msg, parsed_line => $line ) 
+                if $check eq 'yes' ; 
 	    $logger->error($msg) if $check eq 'skip';
         }
         $line++;
@@ -128,7 +129,7 @@ sub _store_line {
     }
     else {
         my $msg = "Did not find a keyword before: '$line''";
-        Config::Model::Exception::Syntax -> throw ( message => $msg, line => $line_nb ) 
+        Config::Model::Exception::Syntax -> throw ( message => $msg, parsed_line => $line_nb ) 
             if $check eq 'yes' ; 
         $logger->error($msg) if $check eq 'skip';
     }
@@ -189,7 +190,7 @@ Config::Model::Backend::Debian::DpkgSyntax - Role to read and write files with D
 
 =head1 VERSION
 
-version 2.008
+version 2.011
 
 =head1 SYNOPSIS
 
