@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -26,8 +26,8 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 package Config::Model::Loader;
-BEGIN {
-  $Config::Model::Loader::VERSION = '1.250';
+{
+  $Config::Model::Loader::VERSION = '2.011';
 }
 use Carp;
 use strict;
@@ -44,7 +44,7 @@ Config::Model::Loader - Load serialized data into config tree
 
 =head1 VERSION
 
-version 1.250
+version 2.011
 
 =head1 SYNOPSIS
 
@@ -265,6 +265,11 @@ C<master>). The experience can be C<intermediate advanced master>.
 The load will raise an exception if the step of the load string tries
 to access an element with experience higher than user's experience.
 
+=item check
+
+Whether to check values while loading. Either C<yes> (default), C<no> or C<skip>.
+Loading with C<skip> will discard bad values.
+
 =back
 
 =cut
@@ -320,7 +325,18 @@ sub load {
 
     #print "command is ",join('+',@command),"\n" ;
 
-    my $ret = $self->_load($node, $check, $experience, \@command,1) ;
+    my $current_node = $node ;
+    my $ret ;
+    do {
+        $ret = $self->_load($current_node, $check, $experience, \@command,1) ;
+        $logger->debug("_load returned $ret") ;
+        
+        # found '!' command
+        if ($ret eq 'root') {
+            $logger->debug("Setting current_node to root node") ;
+            $current_node = $current_node->root ;
+        }
+    } while ($ret eq 'root') ;
 
     if (@command) {
         my $str = "Error: command '@command' was not executed, you may have".
@@ -399,8 +415,8 @@ my %load_dispatch = (
 
 # return 'done', 'root', 'up', 'error'
 sub _load {
-    my ($self, $node, $check, $experience, $cmdref,$is_root) = @_ ;
-    $is_root ||= 0;
+    my ($self, $node, $check, $experience, $cmdref,$at_top_level) = @_ ;
+    $at_top_level ||= 0;
     my $node_name = "'".$node->name."'" ;
     $logger->debug("_load: called on node $node_name");
 
@@ -417,8 +433,8 @@ sub _load {
         next if $cmd =~ /^\s*$/ ;
 
         if ($cmd eq '!') {
-	    $logger->debug("_load: going to root");
-	    next if $is_root ;
+	    $logger->debug("_load: going to root, at_top_level is $at_top_level");
+	    # Do not change current node as we don't want to mess up =~ commands
 	    return 'root' ;
 	}
 
@@ -512,8 +528,14 @@ sub _load {
 	$logger->debug("_load: calling $element_type loader on element $element_name") ;
 	my $ret = $self->$method($node, $check,$experience, \@instructions,$cmdref) ;
 
-	if ($ret eq 'error' or $ret eq 'done') { return $ret; }
-	return 'root' if $ret eq 'root' and not $is_root ;
+	if ($ret eq 'error' or $ret eq 'done') { 
+	    $logger->debug("_load return: $node_name got $ret");
+            return $ret; 
+        }
+	if ($ret eq 'root' and not $at_top_level) {
+            $logger->debug("_load return: $node_name got $ret");
+            return 'root' ;
+        }
 	# ret eq up or ok -> go on with the loop
     }
 
