@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -26,15 +26,62 @@
         'description' => 'If a program needs to specify an architecture specification string in some place, it should select one of the strings provided by dpkg-architecture -L. The strings are in the format os-arch, though the OS part is sometimes elided, as when the OS is Linux. 
 A package may specify an architecture wildcard. Architecture wildcards are in the format any (which matches every architecture), os-any, or any-cpu. For more details, see L<http://www.debian.org/doc/debian-policy/ch-customized-programs.html#s-arch-spec| Debian policy>'
       },
+      'Multi-Arch',
+      {
+        'value_type' => 'enum',
+        'help' => {
+          'foreign' => 'the package is not co-installable with itself, but should be allowed to satisfy the dependency of a package of a different arch from itself.',
+          'allowed' => 'allows reverse-dependencies to indicate in their Depends field that they need a package from a foreign architecture, but has no effect otherwise.',
+          'same' => 'the package is co-installable with itself, but it must not be used to satisfy the dependency of any package of a different architecture from itself.'
+        },
+        'type' => 'leaf',
+        'description' => 'This field is used to indicate how this package should behave on a multi-arch installations. This field should not be present in packages with the Architecture: all field.',
+        'choice' => [
+          'same',
+          'foreign',
+          'allowed'
+        ]
+      },
       'Section',
       {
+        'warn_unless' => {
+          'area' => {
+            'msg' => 'Bad area. Should be \'non-free\' or \'contrib\'',
+            'code' => '(not defined) or m!^((contrib|non-free)/)?\\w+$!;'
+          },
+          'section' => {
+            'msg' => 'Bad section.',
+            'code' => '(not defined) or m!^([-\\w]+/)?(admin|cli-mono|comm|database|devel|debug|doc|editors|education|electronics|embedded|fonts|games|gnome|graphics|gnu-r|gnustep|hamradio|haskell|httpd|interpreters|introspection|java|kde|kernel|libs|libdevel|lisp|localization|mail|math|metapackages|misc|net|news|ocaml|oldlibs|otherosfs|perl|php|python|ruby|science|shells|sound|tex|text|utils|vcs|video|web|x11|xfce|zope)$!;'
+          }
+        },
+        'compute' => {
+          'use_as_upstream_default' => '1',
+          'formula' => '$source',
+          'variables' => {
+            'source' => '- - source Section'
+          }
+        },
         'value_type' => 'uniline',
         'type' => 'leaf'
       },
       'Priority',
       {
-        'value_type' => 'uniline',
-        'type' => 'leaf'
+        'compute' => {
+          'use_as_upstream_default' => '1',
+          'formula' => '$source',
+          'variables' => {
+            'source' => '- - source Priority'
+          }
+        },
+        'value_type' => 'enum',
+        'type' => 'leaf',
+        'choice' => [
+          'required',
+          'important',
+          'standard',
+          'optional',
+          'extra'
+        ]
       },
       'Essential',
       {
@@ -129,6 +176,25 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
         'value_type' => 'enum',
         'summary' => 'The type of the package, if not a regular Debian one',
         'experience' => 'advanced',
+        'migrate_from' => {
+          'formula' => '$xc',
+          'variables' => {
+            'xc' => '- XC-Package-Type'
+          }
+        },
+        'type' => 'leaf',
+        'description' => 'If this field is present, the package is not a regular Debian package, but either a udeb generated for the Debian installer or a tdeb containing translated debconf strings.',
+        'choice' => [
+          'tdeb',
+          'udeb'
+        ]
+      },
+      'XC-Package-Type',
+      {
+        'value_type' => 'enum',
+        'summary' => 'The type of the package, if not a regular Debian one',
+        'status' => 'deprecated',
+        'experience' => 'advanced',
         'type' => 'leaf',
         'description' => 'If this field is present, the package is not a regular Debian package, but either a udeb generated for the Debian installer or a tdeb containing translated debconf strings.',
         'choice' => [
@@ -140,10 +206,6 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
       {
         'value_type' => 'uniline',
         'warn_if_match' => {
-          '^[A-Z]' => {
-            'msg' => 'short description should start with a small letter',
-            'fix' => '$_ = lcfirst($_) ;'
-          },
           '.{60,}' => {
             'msg' => 'Synopsis is too long. '
           }
